Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(102)

Unified Diff: third_party/WebKit/Source/platform/scroll/ScrollableArea.h

Issue 2721133003: Rename platform/Widget to platform/FrameViewBase in platform. (Closed)
Patch Set: Rename platform/Widget to platform/FrameViewBase in platform. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/scroll/ScrollableArea.h
diff --git a/third_party/WebKit/Source/platform/scroll/ScrollableArea.h b/third_party/WebKit/Source/platform/scroll/ScrollableArea.h
index 266e8048a3ea6b78a75b4b005e13d20120d74627..352258227b24878b2ecb276442a0f55a88c33d9c 100644
--- a/third_party/WebKit/Source/platform/scroll/ScrollableArea.h
+++ b/third_party/WebKit/Source/platform/scroll/ScrollableArea.h
@@ -181,28 +181,28 @@ class PLATFORM_EXPORT ScrollableArea : public GarbageCollectedMixin,
void setScrollCornerNeedsPaintInvalidation();
virtual void getTickmarks(Vector<IntRect>&) const {}
// Convert points and rects between the scrollbar and its containing Widget.
// The client needs to implement these in order to be aware of layout effects
// like CSS transforms.
virtual IntRect convertFromScrollbarToContainingWidget(
const Scrollbar& scrollbar,
const IntRect& scrollbarRect) const {
- return scrollbar.Widget::convertToContainingWidget(scrollbarRect);
+ return scrollbar.FrameViewBase::convertToContainingWidget(scrollbarRect);
}
virtual IntRect convertFromContainingWidgetToScrollbar(
const Scrollbar& scrollbar,
const IntRect& parentRect) const {
- return scrollbar.Widget::convertFromContainingWidget(parentRect);
+ return scrollbar.FrameViewBase::convertFromContainingWidget(parentRect);
}
virtual IntPoint convertFromScrollbarToContainingWidget(
const Scrollbar& scrollbar,
const IntPoint& scrollbarPoint) const {
- return scrollbar.Widget::convertToContainingWidget(scrollbarPoint);
+ return scrollbar.FrameViewBase::convertToContainingWidget(scrollbarPoint);
}
virtual IntPoint convertFromContainingWidgetToScrollbar(
const Scrollbar& scrollbar,
const IntPoint& parentPoint) const {
- return scrollbar.Widget::convertFromContainingWidget(parentPoint);
+ return scrollbar.FrameViewBase::convertFromContainingWidget(parentPoint);
}
virtual Scrollbar* horizontalScrollbar() const { return nullptr; }
@@ -336,7 +336,7 @@ class PLATFORM_EXPORT ScrollableArea : public GarbageCollectedMixin,
OverlayScrollbarClipBehavior = IgnoreOverlayScrollbarSize) const;
// Returns the widget associated with this ScrollableArea.
- virtual Widget* getWidget() { return nullptr; }
+ virtual FrameViewBase* getWidget() { return nullptr; }
virtual LayoutBox* layoutBox() const { return nullptr; }

Powered by Google App Engine
@@ -181,28 +181,28 @@ class PLATFORM_EXPORT ScrollableArea : public GarbageCollectedMixin,
void setScrollCornerNeedsPaintInvalidation();
virtual void getTickmarks(Vector<IntRect>&) const {}
- // Convert points and rects between the scrollbar and its containing Widget.
- // The client needs to implement these in order to be aware of layout effects
- // like CSS transforms.
+ // Convert points and rects between the scrollbar and its containing
+ // FrameViewBase. The client needs to implement these in order to be aware of
+ // layout effects like CSS transforms.
virtual IntRect convertFromScrollbarToContainingWidget(
const Scrollbar& scrollbar,
This is Rietveld 408576698